@@ -13,5 +13,5 @@ $JF histo ${pref}.jf > ${pref}.histo
 
 for i in test_mer_file.t test_hash_counter.t; do
     echo Test $i
-    $PERL "-I$LOADPATH/.libs" "-I$LOADPATH" "$SRCDIR/swig/perl5/t/$i" .
+    $PERL "-I$LOADPATH/.libs" "-I$LOADPATH" "-I$SRCDIR/swig/perl5" "$SRCDIR/swig/perl5/t/$i" .
 done
